==> totoui-0.3.0.tgz: package/lib/formGroup.js <==
'use strict';

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _minxinsClassNameMixin = require('./minxins/ClassNameMixin');

var _minxinsClassNameMixin2 = _interopRequireDefault(_minxinsClassNameMixin);

var FormGroup = (function (_React$Component) {
    _inherits(FormGroup, _React$Component);

    function FormGroup(props) {
        _classCallCheck(this, FormGroup);

        _get(Object.getPrototypeOf(FormGroup.prototype), 'constructor', this).call(this, props);
        for (var v in _minxinsClassNameMixin2['default']) {
            this[v] = _minxinsClassNameMixin2['default'][v].bind(this);
        }
    }

    _createClass(FormGroup, [{
        key: 'render',
        value: function render() {
            var classSet = {};

            classSet[this.setClassNamespace('form-group')] = true;
            this.props.validation && (classSet[this.setClassNamespace('form-' + this.props.validation)] = true);
            classSet[this.setClassNamespace('form-feedback')] = this.props.hasFeedback;
            classSet[this.setClassNamespace('form-icon')] = this.props.hasFeedback;

            if (this.props.amSize) {
                classSet[this.setClassNamespace('form-group-' + this.props.amSize)] = true;
            }

            return _react2['default'].createElement(
                'div',
                { className: (0, _classnames2['default'])(classSet, this.props.className) },
                this.props.children
            );
        }
    }]);

    return FormGroup;
})(_react2['default'].Component);

FormGroup.displayName = "FormGroup";

FormGroup.propTypes = {
    validation: _react2['default'].PropTypes.string,
    amSize: _react2['default'].PropTypes.oneOf(['sm', 'lg']),
    hasFeedback: _react2['default'].PropTypes.bool
};

FormGroup.defaultProps = {
    classPrefix: 'formGroup'
};

module.exports = FormGroup;

==> totoui-0.5.1.tgz: package/lib/formGroup.js <==
'use strict';

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _mixinsClassNameMixin = require('./mixins/ClassNameMixin');

var _mixinsClassNameMixin2 = _interopRequireDefault(_mixinsClassNameMixin);

var FormGroup = (function (_React$Component) {
    _inherits(FormGroup, _React$Component);

    function FormGroup(props) {
        _classCallCheck(this, FormGroup);

        _get(Object.getPrototypeOf(FormGroup.prototype), 'constructor', this).call(this, props);
        for (var v in _mixinsClassNameMixin2['default']) {
            this[v] = _mixinsClassNameMixin2['default'][v].bind(this);
        }
    }

    _createClass(FormGroup, [{
        key: 'render',
        value: function render() {
            var classSet = {};

            classSet[this.setClassNamespace('form-group')] = true;
            this.props.validation && (classSet[this.setClassNamespace('form-' + this.props.validation)] = true);
            classSet[this.setClassNamespace('form-feedback')] = this.props.hasFeedback;
            classSet[this.setClassNamespace('form-icon')] = this.props.hasFeedback;

            if (this.props.amSize) {
                classSet[this.setClassNamespace('form-group-' + this.props.amSize)] = true;
            }

            return _react2['default'].createElement(
                'div',
                { className: (0, _classnames2['default'])(classSet, this.props.className) },
                this.props.children
            );
        }
    }]);

    return FormGroup;
})(_react2['default'].Component);

FormGroup.displayName = "FormGroup";

FormGroup.propTypes = {
    validation: _react2['default'].PropTypes.string,
    amSize: _react2['default'].PropTypes.oneOf(['sm', 'lg']),
    hasFeedback: _react2['default'].PropTypes.bool
};

FormGroup.defaultProps = {
    classPrefix: 'formGroup'
};

module.exports = FormGroup;
